/*
 * A very simple GNOME Shell extension that lets users toggle the
 * LookingGlass window by pressing a top panel button.
 * Copyright (C) 2012  Andrea Santilli <andresantilli gmx com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

const Lang      = imports.lang;
const Main      = imports.ui.main;
const Panel     = imports.ui.panel;
const PanelMenu = imports.ui.panelMenu;
const St        = imports.gi.St;

const TOOLTIP   = 'toggle LookingGlass';
const ICON_NAME = 'preferences-desktop-display';
const ICON_TYPE = St.IconType.SYMBOLIC;
const ROLE      = 'lgbutton';

/* we want our button to show the same layout of a PanelMenu.Button; we
 * inherit from PanelMenu.ButtonBox though, as we don't need any menus. */
LookingGlassButton.prototype = {
    __proto__: PanelMenu.ButtonBox.prototype,

    _init: function(metadata, params)
    {
        PanelMenu.ButtonBox.prototype._init.call(this, {
            reactive: true,
            can_focus: true,
            track_hover: true
        });

        /* setup icon and style */
        this.actor.add_actor(new St.Icon({
            icon_name: ICON_NAME,
            icon_type: ICON_TYPE,
            style_class: 'system-status-icon'
        }));
        this.actor.add_style_class_name('panel-status-button');
        
        /* setup tooltip */
        this.actor.has_tooltip = true;
        this.actor.tooltip_text = TOOLTIP;

        this.actor.connect('button-press-event', Lang.bind(this, function () {
            /* this call doesn't create a new instance of LG when there's
             * already one.*/
            Main.createLookingGlass();
            Main.lookingGlass.toggle();
        }));

        /* we can't directly call Main.panel.addToStatusArea() as this object
         * is not an instance of PanelMenu.Button */
        Main.panel._insertStatusItem(this.actor, 0);
        Main.panel._statusArea[ROLE] = this;
    },

    destroy: function() {
        /* remove this button from the status area first */
        Main.panel._statusArea[ROLE] = null;

        this.actor._delegate = null;
        this.actor.destroy();
        this.actor.emit('destroy');
    }
};

function LookingGlassButton() {
    this._init.apply(this, arguments);
}

let lgb;

function init() {}

function enable() {
    lgb = new LookingGlassButton();
}

function disable() {
    lgb.destroy();
}

